@@ -4,12 +4,12 @@
 <context>
     <name>AboutDialog</name>
     <message>
-        <location filename="../AboutDialog.qml" line="36"/>
-        <source>cuteTube-QML - 0.4.4</source>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.5.1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="48"/>
+        <location filename="../AboutDialog.qml" line="56"/>
         <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
         <translation></translation>
     </message>
@@ -33,17 +33,17 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="89"/>
+        <location filename="../AccountDetailsDialog.qml" line="82"/>
         <source>Username</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="114"/>
+        <location filename="../AccountDetailsDialog.qml" line="107"/>
         <source>Password</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../AccountDetailsDialog.qml" line="139"/>
+        <location filename="../AccountDetailsDialog.qml" line="132"/>
         <source>Default?</source>
         <translation></translation>
     </message>
@@ -51,7 +51,7 @@
 <context>
     <name>AccountsDialog</name>
     <message>
-        <location filename="../AccountsDialog.qml" line="81"/>
+        <location filename="../AccountsDialog.qml" line="79"/>
         <source>YouTube Accounts</source>
         <translation></translation>
     </message>
@@ -68,11 +68,26 @@
         <source>Share Via </source>
         <translation></translation>
     </message>
+    <message>
+        <location filename="../AddCommentDialog.qml" line="60"/>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../AddCommentDialog.qml" line="87"/>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../AddCommentDialog.qml" line="124"/>
+        <source>Message</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AddToPlaylistDialog</name>
     <message>
-        <location filename="../AddToPlaylistDialog.qml" line="24"/>
+        <location filename="../AddToPlaylistDialog.qml" line="31"/>
         <source>Add To Playlist</source>
         <translation></translation>
     </message>
@@ -106,7 +121,7 @@
 <context>
     <name>ChangeUserDialog</name>
     <message>
-        <location filename="../ChangeUserDialog.qml" line="44"/>
+        <location filename="../ChangeUserDialog.qml" line="50"/>
         <source>Change Current User</source>
         <translation></translation>
     </message>
@@ -129,22 +144,22 @@
 <context>
     <name>ConfirmExitDialog</name>
     <message>
-        <location filename="../ConfirmExitDialog.qml" line="62"/>
+        <location filename="../ConfirmExitDialog.qml" line="47"/>
         <source>Hold it!</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../ConfirmExitDialog.qml" line="73"/>
+        <location filename="../ConfirmExitDialog.qml" line="58"/>
         <source>cuteTube is currently downloading. Do you really want to exit?</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../ConfirmExitDialog.qml" line="85"/>
+        <location filename="../ConfirmExitDialog.qml" line="71"/>
         <source>Yes</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../ConfirmExitDialog.qml" line="97"/>
+        <location filename="../ConfirmExitDialog.qml" line="81"/>
         <source>No</source>
         <translation></translation>
     </message>
@@ -218,7 +233,7 @@
 <context>
     <name>FileChooserDialog</name>
     <message>
-        <location filename="../FileChooserDialog.qml" line="36"/>
+        <location filename="../FileChooserDialog.qml" line="29"/>
         <source>Choose Video File</source>
         <translation></translation>
     </message>
@@ -226,37 +241,37 @@
 <context>
     <name>HomeView</name>
     <message>
-        <location filename="../HomeView.qml" line="124"/>
+        <location filename="../HomeView.qml" line="102"/>
         <source>Settings</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="124"/>
+        <location filename="../HomeView.qml" line="102"/>
         <source>Accounts</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="124"/>
+        <location filename="../HomeView.qml" line="102"/>
         <source>About</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="177"/>
+        <location filename="../HomeView.qml" line="154"/>
         <source>My Channel</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="202"/>
+        <location filename="../HomeView.qml" line="178"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="227"/>
+        <location filename="../HomeView.qml" line="202"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../HomeView.qml" line="252"/>
+        <location filename="../HomeView.qml" line="226"/>
         <source>Archive</source>
         <translation></translation>
     </message>
@@ -282,42 +297,42 @@
 <context>
     <name>MyAccountView</name>
     <message>
-        <location filename="../MyAccountView.qml" line="107"/>
+        <location filename="../MyAccountView.qml" line="75"/>
         <source>Upload video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="147"/>
+        <location filename="../MyAccountView.qml" line="115"/>
         <source>My Uploads</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="154"/>
+        <location filename="../MyAccountView.qml" line="121"/>
         <source>Uploads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="172"/>
+        <location filename="../MyAccountView.qml" line="139"/>
         <source>My Favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="179"/>
+        <location filename="../MyAccountView.qml" line="145"/>
         <source>Favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="204"/>
+        <location filename="../MyAccountView.qml" line="169"/>
         <source>Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="229"/>
+        <location filename="../MyAccountView.qml" line="193"/>
         <source>Subscriptions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="244"/>
+        <location filename="../MyAccountView.qml" line="208"/>
         <source>Signed in as:</source>
         <translation></translation>
     </message>
@@ -325,22 +340,22 @@
 <context>
     <name>NewPlaylistDialog</name>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="28"/>
+        <location filename="../NewPlaylistDialog.qml" line="34"/>
         <source>New Playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="40"/>
+        <location filename="../NewPlaylistDialog.qml" line="46"/>
         <source>Title</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="65"/>
+        <location filename="../NewPlaylistDialog.qml" line="71"/>
         <source>Description (optional)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../NewPlaylistDialog.qml" line="89"/>
+        <location filename="../NewPlaylistDialog.qml" line="95"/>
         <source>Private?</source>
         <translation></translation>
     </message>
@@ -348,22 +363,22 @@
 <context>
     <name>NoAccountDialog</name>
     <message>
-        <location filename="../NoAccountDialog.qml" line="62"/>
+        <location filename="../NoAccountDialog.qml" line="60"/>
         <source>Hi there!</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../NoAccountDialog.qml" line="73"/>
+        <location filename="../NoAccountDialog.qml" line="71"/>
         <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../NoAccountDialog.qml" line="85"/>
+        <location filename="../NoAccountDialog.qml" line="84"/>
         <source>Yes</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../NoAccountDialog.qml" line="102"/>
+        <location filename="../NoAccountDialog.qml" line="98"/>
         <source>Go Away</source>
         <translation></translation>
     </message>
@@ -389,12 +404,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../OAuthDialog.qml" line="26"/>
+        <location filename="../OAuthDialog.qml" line="27"/>
         <source>Error obtaining facebook authorisation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../OAuthDialog.qml" line="123"/>
+        <location filename="../OAuthDialog.qml" line="117"/>
         <source>Enter pin code</source>
         <translation type="unfinished"></translation>
     </message>
@@ -410,37 +425,37 @@
 <context>
     <name>PlaylistVideosView</name>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="60"/>
         <source>Multi-select</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="92"/>
+        <location filename="../PlaylistVideosView.qml" line="62"/>
         <source>Download video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="92"/>
+        <location filename="../PlaylistVideosView.qml" line="62"/>
         <source>Download audio</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="93"/>
+        <location filename="../PlaylistVideosView.qml" line="63"/>
         <source>Add to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="93"/>
+        <location filename="../PlaylistVideosView.qml" line="63"/>
         <source>Add to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="93"/>
+        <location filename="../PlaylistVideosView.qml" line="63"/>
         <source>Copy to clipboard</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="147"/>
+        <location filename="../PlaylistVideosView.qml" line="117"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
@@ -448,17 +463,17 @@
 <context>
     <name>PlaylistsView</name>
     <message>
-        <location filename="../PlaylistsView.qml" line="64"/>
+        <location filename="../PlaylistsView.qml" line="61"/>
         <source>New playlist created</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistsView.qml" line="143"/>
+        <location filename="../PlaylistsView.qml" line="109"/>
         <source>New playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../PlaylistsView.qml" line="171"/>
+        <location filename="../PlaylistsView.qml" line="137"/>
         <source>No playlists found</source>
         <translation></translation>
     </message>
@@ -497,85 +512,85 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="127"/>
+        <location filename="../SettingsDialog.qml" line="125"/>
         <source>Your saved searches have been cleared</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="130"/>
+        <location filename="../SettingsDialog.qml" line="128"/>
         <source>Database error. Unable to clear searches</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="183"/>
+        <location filename="../SettingsDialog.qml" line="177"/>
         <source>Settings</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="217"/>
+        <location filename="../SettingsDialog.qml" line="211"/>
         <source>Playback quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="225"/>
+        <location filename="../SettingsDialog.qml" line="219"/>
         <source>Download quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="233"/>
+        <location filename="../SettingsDialog.qml" line="227"/>
         <source>Start downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="241"/>
+        <location filename="../SettingsDialog.qml" line="235"/>
         <source>Download location</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="249"/>
+        <location filename="../SettingsDialog.qml" line="243"/>
         <source>Screen orientation</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="257"/>
+        <location filename="../SettingsDialog.qml" line="251"/>
         <source>Media player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="118"/>
-        <location filename="../SettingsDialog.qml" line="274"/>
-        <location filename="../SettingsDialog.qml" line="428"/>
+        <location filename="../SettingsDialog.qml" line="116"/>
+        <location filename="../SettingsDialog.qml" line="268"/>
+        <location filename="../SettingsDialog.qml" line="422"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="97"/>
-        <location filename="../SettingsDialog.qml" line="300"/>
+        <location filename="../SettingsDialog.qml" line="95"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
         <source>Playback Quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="100"/>
-        <location filename="../SettingsDialog.qml" line="318"/>
+        <location filename="../SettingsDialog.qml" line="98"/>
+        <location filename="../SettingsDialog.qml" line="312"/>
         <source>Download Quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="103"/>
-        <location filename="../SettingsDialog.qml" line="336"/>
+        <location filename="../SettingsDialog.qml" line="101"/>
+        <location filename="../SettingsDialog.qml" line="330"/>
         <source>Start Downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="109"/>
-        <location filename="../SettingsDialog.qml" line="374"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
+        <location filename="../SettingsDialog.qml" line="368"/>
         <source>Screen Orientation</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="112"/>
-        <location filename="../SettingsDialog.qml" line="392"/>
+        <location filename="../SettingsDialog.qml" line="110"/>
+        <location filename="../SettingsDialog.qml" line="386"/>
         <source>Media Player</source>
         <translation></translation>
     </message>
@@ -657,24 +672,24 @@
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="74"/>
-        <location filename="../SettingsDialog.qml" line="106"/>
+        <location filename="../SettingsDialog.qml" line="104"/>
         <source>Download Path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="77"/>
+        <location filename="../SettingsDialog.qml" line="76"/>
         <source>Download Location</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="115"/>
-        <location filename="../SettingsDialog.qml" line="265"/>
-        <location filename="../SettingsDialog.qml" line="410"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="259"/>
+        <location filename="../SettingsDialog.qml" line="404"/>
         <source>Theme</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="442"/>
+        <location filename="../SettingsDialog.qml" line="436"/>
         <source>Clear saved searches</source>
         <translation></translation>
     </message>
@@ -682,7 +697,7 @@
 <context>
     <name>Sharing</name>
     <message>
-        <location filename="../../../sharing.cpp" line="76"/>
+        <location filename="../../../sharing.cpp" line="78"/>
         <source>Error - Server repsonse is: </source>
         <translation type="unfinished"></translation>
     </message>
@@ -690,18 +705,18 @@
 <context>
     <name>SubscriptionsView</name>
     <message>
-        <location filename="../SubscriptionsView.qml" line="44"/>
+        <location filename="../SubscriptionsView.qml" line="48"/>
         <source>You have unsubscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="140"/>
-        <location filename="../SubscriptionsView.qml" line="155"/>
+        <location filename="../SubscriptionsView.qml" line="107"/>
+        <location filename="../SubscriptionsView.qml" line="122"/>
         <source>Latest Subscription Videos</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="168"/>
+        <location filename="../SubscriptionsView.qml" line="135"/>
         <source>No subscriptions found</source>
         <translation></translation>
     </message>
@@ -785,44 +800,44 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="36"/>
-        <location filename="../UploadDialog.qml" line="258"/>
+        <location filename="../UploadDialog.qml" line="35"/>
+        <location filename="../UploadDialog.qml" line="251"/>
         <source>Category</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="122"/>
+        <location filename="../UploadDialog.qml" line="114"/>
         <source>Upload Video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="145"/>
+        <location filename="../UploadDialog.qml" line="138"/>
         <source>File</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="154"/>
-        <location filename="../UploadDialog.qml" line="266"/>
+        <location filename="../UploadDialog.qml" line="147"/>
+        <location filename="../UploadDialog.qml" line="259"/>
         <source>None chosen</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="170"/>
+        <location filename="../UploadDialog.qml" line="163"/>
         <source>Title</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="195"/>
+        <location filename="../UploadDialog.qml" line="188"/>
         <source>Description (optional)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="219"/>
+        <location filename="../UploadDialog.qml" line="212"/>
         <source>Tags (seperated by commas)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="244"/>
+        <location filename="../UploadDialog.qml" line="237"/>
         <source>Private?</source>
         <translation></translation>
     </message>
@@ -835,34 +850,34 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../UploadProgressDialog.qml" line="34"/>
+        <location filename="../UploadProgressDialog.qml" line="30"/>
         <source>Upload Progress</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadProgressDialog.qml" line="46"/>
+        <location filename="../UploadProgressDialog.qml" line="42"/>
         <source>Filename</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadProgressDialog.qml" line="61"/>
+        <location filename="../UploadProgressDialog.qml" line="57"/>
         <source>Title</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadProgressDialog.qml" line="95"/>
+        <location filename="../UploadProgressDialog.qml" line="91"/>
         <source>Abort</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadProgressDialog.qml" line="95"/>
+        <location filename="../UploadProgressDialog.qml" line="91"/>
         <source>Close</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadProgressDialog.qml" line="95"/>
-        <location filename="../UploadProgressDialog.qml" line="101"/>
-        <location filename="../UploadProgressDialog.qml" line="119"/>
+        <location filename="../UploadProgressDialog.qml" line="91"/>
+        <location filename="../UploadProgressDialog.qml" line="97"/>
+        <location filename="../UploadProgressDialog.qml" line="115"/>
         <source>Upload is in progress</source>
         <translation type="unfinished"></translation>
     </message>
@@ -870,12 +885,12 @@
 <context>
     <name>UserInfoDialog</name>
     <message>
-        <location filename="../UserInfoDialog.qml" line="111"/>
+        <location filename="../UserInfoDialog.qml" line="120"/>
         <source>Subscribers</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserInfoDialog.qml" line="125"/>
+        <location filename="../UserInfoDialog.qml" line="134"/>
         <source>Videos</source>
         <translation></translation>
     </message>
@@ -883,67 +898,67 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="83"/>
+        <location filename="../UserVideosView.qml" line="84"/>
         <source>You have subscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="87"/>
+        <location filename="../UserVideosView.qml" line="88"/>
         <source>You have unsubscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="140"/>
+        <location filename="../UserVideosView.qml" line="110"/>
         <source>Multi-select</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="142"/>
+        <location filename="../UserVideosView.qml" line="112"/>
         <source>Download video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="142"/>
+        <location filename="../UserVideosView.qml" line="112"/>
         <source>Download audio</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="143"/>
+        <location filename="../UserVideosView.qml" line="113"/>
         <source>Add to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="143"/>
+        <location filename="../UserVideosView.qml" line="113"/>
         <source>Add to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="143"/>
+        <location filename="../UserVideosView.qml" line="113"/>
         <source>Copy to clipboard</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="196"/>
+        <location filename="../UserVideosView.qml" line="166"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="248"/>
+        <location filename="../UserVideosView.qml" line="218"/>
         <source>Subscribers</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="262"/>
+        <location filename="../UserVideosView.qml" line="232"/>
         <source>Videos</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="285"/>
+        <location filename="../UserVideosView.qml" line="255"/>
         <source>Unsubscribe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="285"/>
+        <location filename="../UserVideosView.qml" line="255"/>
         <source>Subscribe</source>
         <translation></translation>
     </message>
@@ -951,7 +966,7 @@
 <context>
     <name>VideoInfoView</name>
     <message>
-        <location filename="../VideoInfoView.qml" line="15"/>
+        <location filename="../VideoInfoView.qml" line="16"/>
         <source>No description</source>
         <translation></translation>
     </message>
@@ -971,82 +986,82 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="135"/>
+        <location filename="../VideoInfoView.qml" line="103"/>
         <source>Add to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="135"/>
+        <location filename="../VideoInfoView.qml" line="103"/>
         <source>Add to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="135"/>
+        <location filename="../VideoInfoView.qml" line="103"/>
         <source>Copy to clipboard</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="136"/>
+        <location filename="../VideoInfoView.qml" line="104"/>
         <source>Share via facebook</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="155"/>
-        <location filename="../VideoInfoView.qml" line="163"/>
-        <location filename="../VideoInfoView.qml" line="501"/>
-        <location filename="../VideoInfoView.qml" line="525"/>
-        <location filename="../VideoInfoView.qml" line="630"/>
+        <location filename="../VideoInfoView.qml" line="123"/>
+        <location filename="../VideoInfoView.qml" line="131"/>
+        <location filename="../VideoInfoView.qml" line="470"/>
+        <location filename="../VideoInfoView.qml" line="494"/>
+        <location filename="../VideoInfoView.qml" line="599"/>
         <source>You are not signed in to a YouTube account</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="302"/>
+        <location filename="../VideoInfoView.qml" line="271"/>
         <source>Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="341"/>
+        <location filename="../VideoInfoView.qml" line="310"/>
         <source>Comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="380"/>
+        <location filename="../VideoInfoView.qml" line="349"/>
         <source>Related</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="471"/>
-        <location filename="../VideoInfoView.qml" line="474"/>
+        <location filename="../VideoInfoView.qml" line="440"/>
+        <location filename="../VideoInfoView.qml" line="443"/>
         <source>By </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="542"/>
+        <location filename="../VideoInfoView.qml" line="511"/>
         <source>Views</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="556"/>
+        <location filename="../VideoInfoView.qml" line="525"/>
         <source>Description</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="572"/>
+        <location filename="../VideoInfoView.qml" line="541"/>
         <source>Tags</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="642"/>
+        <location filename="../VideoInfoView.qml" line="611"/>
         <source>No comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="642"/>
+        <location filename="../VideoInfoView.qml" line="611"/>
         <source> comments</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="736"/>
+        <location filename="../VideoInfoView.qml" line="704"/>
         <source>No related videos</source>
         <translation></translation>
     </message>
@@ -1072,37 +1087,37 @@
 <context>
     <name>VideoListView</name>
     <message>
-        <location filename="../VideoListView.qml" line="87"/>
+        <location filename="../VideoListView.qml" line="57"/>
         <source>Multi-select</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="89"/>
+        <location filename="../VideoListView.qml" line="59"/>
         <source>Download video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="89"/>
+        <location filename="../VideoListView.qml" line="59"/>
         <source>Download audio</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="90"/>
+        <location filename="../VideoListView.qml" line="60"/>
         <source>Add to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="90"/>
+        <location filename="../VideoListView.qml" line="60"/>
         <source>Add to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="90"/>
+        <location filename="../VideoListView.qml" line="60"/>
         <source>Copy to clipboard</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="144"/>
+        <location filename="../VideoListView.qml" line="114"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
@@ -1177,64 +1192,64 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="91"/>
+        <location filename="../main.qml" line="103"/>
         <source>Video(s) added to download queue</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="102"/>
+        <location filename="../main.qml" line="114"/>
         <source>Audio track(s) added to download queue</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="123"/>
+        <location filename="../main.qml" line="145"/>
         <source>Video added to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="124"/>
+        <location filename="../main.qml" line="146"/>
         <source>Video added to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="131"/>
+        <location filename="../main.qml" line="153"/>
         <source>New playlist created</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="171"/>
+        <location filename="../main.qml" line="193"/>
         <source>Converting</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="180"/>
+        <location filename="../main.qml" line="202"/>
         <source>Conversion of &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="180"/>
+        <location filename="../main.qml" line="202"/>
         <source>&apos; failed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="194"/>
-        <location filename="../main.qml" line="201"/>
-        <location filename="../main.qml" line="241"/>
+        <location filename="../main.qml" line="216"/>
+        <location filename="../main.qml" line="223"/>
+        <location filename="../main.qml" line="263"/>
         <source>Queued</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="209"/>
+        <location filename="../main.qml" line="231"/>
         <source>Paused</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="389"/>
+        <location filename="../main.qml" line="411"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="390"/>
+        <location filename="../main.qml" line="412"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
