@@ -233,7 +233,7 @@ function youtubeSearch(query, order) {
     }
 
     var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=none&q="
-                     + escape(query).replace(" ", "+") + "&orderby=" + searchOrder);
+                     + encodeURIComponent(query).replace(" ", "+") + "&orderby=" + searchOrder);
     loadVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
 }
 
