@@ -37,10 +37,10 @@ function shareVideo(service) {
     if (dimmer.state == "") {
         toggleControls(false);
         if (service == "Twitter") {
-            checkTwitterAccess(videoId);
+            checkTwitterAccess();
         }
         else if (service == "Facebook") {
-            checkFacebookAccess(videoId);
+            checkFacebookAccess();
         }
     }
 }
@@ -51,7 +51,7 @@ function showAddCommentDialog() {
     if (dimmer.state == "") {
         toggleControls(false);
         var commentDialog = ObjectCreator.createObject("AddCommentDialog.qml", window);
-        commentDialog.setService("YouTube", videoId);
+        commentDialog.setService("YouTube", video);
         commentDialog.close.connect(closeDialogs);
         dimmer.state = "dim";
         commentDialog.state = "show";
@@ -71,7 +71,7 @@ function closeDialogs() {
 function checkFacebookAccess() {
     if (Sharing.facebookToken != "unknown") {
         var shareDialog = ObjectCreator.createObject("AddCommentDialog.qml", window);
-        shareDialog.setService("Facebook", videoId);
+        shareDialog.setService("Facebook", video);
         shareDialog.close.connect(closeDialogs);
         dimmer.state = "dim";
         shareDialog.state = "show";
